from setuptools import setup

setup(
    name = 'greet-human',
    packages =['human'],
    version = '1.0.0',
    license= 'MIT',
    description='This package is used to greet people.',
    author = ' Prajol Shrestha',
    author_email = 'prajolstha9@gmail.com',
    url='https://example.com',
    keywords=['human','greet'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.10',
    ],

)